@@ -41,8 +41,9 @@ def find_start_dirs(start_from: Path = None) -> List[Path]:
         start_from = Path('.')
     start_from = start_from.absolute()
 
-    # TODO this can be rewritten more effectively with recursion, that does
-    # not go deeper once "__init__.py" is found
+    if (start_from/"__init__.py").exists():
+        return [start_from]
+
     dirs = []
     for subdir in start_from.glob("*"):
         if subdir.name.startswith('.'):
@@ -154,7 +155,7 @@ def run(
                 pattern=pattern)
             print(
                 f'Module "{rel_to_top(Path(sd))}" contains '
-                f'{suite.countTestCases()} test cases')
+                f'{suite.countTestCases()} tests')
             if suite.countTestCases() > 0:
                 suites.append(suite)
 
